@@ -198,4 +198,4 @@ class TestPyVx(object):
         fcnt = 1
         while g.process() == SUCCESS:
             fcnt += 1
-        assert fcnt > 100
+        assert fcnt == 136
